/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2009 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

\*---------------------------------------------------------------------------*/

#include "gasoline.H"
#include "addToRunTimeSelectionTable.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
    defineTypeNameAndDebug(gasoline, 0);
    addToRunTimeSelectionTable(liquid, gasoline,);
    addToRunTimeSelectionTable(liquid, gasoline, Istream);
}

// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //

Foam::gasoline::gasoline()
:
// the gasoline liquid properties are approximated based on gasoline surrotates in mole fraction except mole weight and critical temperature
    liquid(113.228, 548.00, 3.12419e+6, 0.411, 0.265, 171.80, 4.05773e-2, 376.30, 0.0, 0.2941, 1.5669e+4),
    rho_(),
    pv_(),
    hl_(),
    cp_(),
    // NN: enthalpy, h_, is not used in the sprayModel.
    // For consistency, the enthalpy is derived from hlat and hl.
    // It is, however, convenient to have it available.
    h_(),
    cpg_(),
    // B is the same as n-octane C8H18;	
    B_(0.00239777293379205, -2.81394717721109, -585042.589139551, -1.11265768486663e+18, 1.40968738783693e+20),
    mu_(),
    //Mug is approximated using mole fraction of gasoline surrogates
    mug_(7.77735e-08, 8.30817e-01, 4.83952e+01, 0.0),
    K_(),
    //Kg is approximated using mole fraction of gasoline surrogates
    Kg_(-6.98476e-03, 1.20363e+00, -3.00945e+02, -2.40050e+05),
    sigma_(),
    D_(147.18, 20.1, 114.231, 28) // NN: Same as nHeptane
{}


Foam::gasoline::gasoline
(
    const liquid& l,
    const NSRDSfuncgRho& density,
    const NSRDSfuncgPv& vapourPressure,
    const NSRDSfuncgHl& heatOfVapourisation,
    const NSRDSfuncgCp& heatCapacity,
    const NSRDSfuncgH& enthalpy,
    const NSRDSfuncgCpg& idealGasHeatCapacity,
    const NSRDSfunc4& secondVirialCoeff,
    const NSRDSfuncgMu& dynamicViscosity,
    const NSRDSfunc2& vapourDynamicViscosity,
    const NSRDSfuncgK& thermalConductivity,
    const NSRDSfunc2& vapourThermalConductivity,
    const NSRDSfuncgSigma& surfaceTension,
    const APIdiffCoefFunc& vapourDiffussivity
)
:
    liquid(l),
    rho_(density),
    pv_(vapourPressure),
    hl_(heatOfVapourisation),
    cp_(heatCapacity),
    h_(enthalpy),
    cpg_(idealGasHeatCapacity),
    B_(secondVirialCoeff),
    mu_(dynamicViscosity),
    mug_(vapourDynamicViscosity),
    K_(thermalConductivity),
    Kg_(vapourThermalConductivity),
    sigma_(surfaceTension),
    D_(vapourDiffussivity)
{}


Foam::gasoline::gasoline(Istream& is)
:
    liquid(is),
    rho_(is),
    pv_(is),
    hl_(is),
    cp_(is),
    h_(is),
    cpg_(is),
    B_(is),
    mu_(is),
    mug_(is),
    K_(is),
    Kg_(is),
    sigma_(is),
    D_(is)
{}


// ************************************************************************* //
